#include "p7.h"
#include <qvbox.h>
#include <qlineedit.h>
#include <dcopclient.h>
#include <kfiledialog.h>
#include <kapp.h>
#include <kmenubar.h>
#include <ktoolbar.h>
#include <klocale.h>
#include <kpopupmenu.h>
#include <khtml_part.h>
#include <kdebug.h>
#include <kconfig.h>
#include <kiconloader.h>


#define TOOLBAR_ID_ADDBOOKMARK 1
#define TOOLBAR_ID_BACK 2
#define TOOLBAR_ID_QUIT 3

MainWindow::MainWindow ( const char * name ) : KMainWindow ( 0L, name ), 
DCOPObject ( "browser" )
{
  setCaption("p7");
  QPopupMenu * filemenu = new QPopupMenu;
  filemenu->insertItem( i18n( "&Set default page" ), 
      this, SLOT( fileSetDefaultPage() ) );
  filemenu->insertItem( i18n( "&Quit" ), kapp, SLOT( quit() ) );
  QString about =
    i18n("p7 1.0\n\n"
	"(C) 1999-2002 Antonio Larrosa Jimenez\n"
	"larrosa@kde.org\t\tantlarr@supercable.es\n"
	"Malaga (Spain)\n\n"
	"Simple KDE Tutorial\n"
	"This tutorial comes with ABSOLUTELY NO WARRANTY \n"
	"This is free software, and you are welcome to redistribute it\n"
	"under certain conditions\n");

  QPopupMenu *helpmenu = helpMenu(about);  
  KMenuBar * menu = menuBar();
  menu->insertItem( i18n( "&File" ), filemenu);
  menu->insertSeparator();
  menu->insertItem(i18n( "&Help" ), helpmenu);

  KToolBar *toolbar=new KToolBar(this);

  toolbar->insertButton(BarIcon("reload"), TOOLBAR_ID_ADDBOOKMARK,
      SIGNAL(clicked(int)),this,SLOT(bookLocation()),TRUE,
      i18n("Add to Bookmarks"));  
  toolbar->insertButton(BarIcon("back"), TOOLBAR_ID_BACK,
      SIGNAL(clicked(int)),this,SLOT(gotoPreviousPage()),
      FALSE, i18n("Back to previous page"));  
  toolbar->insertButton(BarIcon("exit"), TOOLBAR_ID_QUIT,
      SIGNAL(clicked(int)),kapp,SLOT(quit()),TRUE,
      i18n("Quit the application"));  
  addToolBar(toolbar); 

  QVBox * vbox = new QVBox ( this );

  location = new QLineEdit ( vbox );

  KConfig *config=kapp->config();
  config->setGroup("Settings");
  location->setText( config->readEntry( "defaultPage", "http://localhost") );

  connect( location , SIGNAL( returnPressed() ),
      this, SLOT( changeLocation() ) );

  browser=new KHTMLPart( vbox );
  browser->openURL( location->text() );

  connect( browser->browserExtension(),
      SIGNAL( openURLRequest( const KURL &, const KParts::URLArgs & ) ),
      this, SLOT( openURLRequest(const KURL &, const KParts::URLArgs & ) ) );

  setCentralWidget( vbox );

  DCOPClient *client = kapp->dcopClient();
  client->attach();
  client->registerAs("p7");
}


void MainWindow::changeLocation()
{
  history.push( browser->url().url() );
  toolBar()->setItemEnabled( TOOLBAR_ID_BACK, TRUE);
  browser->openURL( location->text() );
}

void MainWindow::setURL( const QString url )
{
  location->setText( url );
  changeLocation();
}

void MainWindow::openURLRequest( const KURL &url, const KParts::URLArgs & )
{
  setURL( url.url() );
}

void MainWindow::gotoPreviousPage()
{
  location->setText( history.pop() );
  if (history.isEmpty()) toolBar()->setItemEnabled( TOOLBAR_ID_BACK, FALSE);
  browser->openURL( location->text() );
}

void MainWindow::bookLocation()
{
  DCOPClient *client=kapp->dcopClient();
  QByteArray params;
  QDataStream stream(params, IO_WriteOnly);
  stream << location->text();
  if (!client->send("p8-*", "bookmarkList", "add(QString)", params))
    kdDebug() << "Error with DCOP\n";
}

void MainWindow::fileSetDefaultPage()
{
  KConfig *config=kapp->config();

  config->setGroup("Settings");
  config->writeEntry( "defaultPage", browser->url().url() );
}
